params

package
v0.0.0-...-00235aa Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Aug 9, 2021 License: GPL-3.0 Imports: 4 Imported by: 0

Documentation

Overview

Package params defines the Params data type and functions

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

This section is empty.

Types

type Params

type Params struct {
	Help           bool
	Pattern        string
	Command        string
	Recursive      bool
	IntervalMillis int
	ResourceFile   string
}

Params holds the settings collected from .eyerc and overidden by arguments

func (*Params) AddParamsFromCommandLine

func (ps *Params) AddParamsFromCommandLine() error

AddParamsFromCommandLine initializes flags and options

func (*Params) AddParamsFromResourceFile

func (ps *Params) AddParamsFromResourceFile(fs []string) error

AddParamsFromResourceFile reads the fs file and sets the values

Jump to