Documentation
¶
Overview ¶
Package params defines the Params data type and functions
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type Params ¶
type Params struct {
Help bool
Pattern string
Command string
Recursive bool
IntervalMillis int
ResourceFile string
}
Params holds the settings collected from .eyerc and overidden by arguments
func (*Params) AddParamsFromCommandLine ¶
AddParamsFromCommandLine initializes flags and options
func (*Params) AddParamsFromResourceFile ¶
AddParamsFromResourceFile reads the fs file and sets the values
Click to show internal directories.
Click to hide internal directories.