Documentation
¶
Overview ¶
Package watcher Status data type
Package watcher defines the type that watches the files for changes matching a pattern in a file structure on an interval
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func RunSystemCommand ¶
RunSystemCommand runs the command and display the output during the execution Can be used by client when wrapped in anonymous func
Types ¶
type Status ¶
type Status struct {
Type StatusType
File string
Message string
}
Status data type hold info about one watched file
type StatusType ¶
type StatusType int
StatusType is the status of a watched file
const ( StatusNone StatusType = iota StatusInfo StatusModified StatusDeleted StatusAdded )
Statuses of StatusType
Click to show internal directories.
Click to hide internal directories.